==> limberer-0.2.tar.gz: limberer-0.2/src/limberer/static/sections/example2.md <==
---
columns: true
---

## AAA

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam volutpat faucibus vestibulum.
Mauris varius orci quam. Nam dui mauris, dictum at elementum at, mollis pulvinar est.
Nunc lobortis pharetra erat, id rutrum lorem malesuada in.

## BBB

Phasellus id nisl nec arcu tempor ultricies non id tortor. Mauris ex nibh, viverra vitae nisi eget, placerat pharetra est.
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed id maximus diam. Cras molestie nisl vitae iaculis convallis.
Vivamus molestie vitae nisl sed interdum. Nunc aliquam massa rhoncus finibus convallis.
Vivamus sed vulputate risus. Nunc dignissim magna velit, quis lobortis ex volutpat eget.
Proin dictum mauris condimentum consequat faucibus.

## CCC

* Foo
* Bar
* Baz

<div class="columnbreak"></div>

## DDD

Suspendisse et gravida nunc. Quisque at felis nisl. Nam eget efficitur nunc.
Vivamus fermentum imperdiet massa, porttitor elementum mauris faucibus scelerisque.
Pellentesque ut metus tortor. Fusce vulputate ex at turpis consectetur, in vestibulum odio placerat.
Suspendisse tempor sapien rutrum, cursus sem a, tincidunt odio. Sed in consequat augue.
Proin finibus felis neque, ac hendrerit lorem consequat nec.

## EEE

**Orci varius** _natoque penatibus_ et magnis dis parturient montes, nascetur ridiculus mus. Fusce quam mi, dapibus et augue sit amet, porttitor volutpat orci.
Vestibulum ac ligula at justo placerat pulvinar vel non velit. Duis vel iaculis nibh, non tristique lectus.
Phasellus vel ex bibendum, accumsan tellus a, commodo nisi.

==> limberer-0.3.3.tar.gz: limberer-0.3.3/src/limberer/static/sections/example2.md <==
---
columns: true
foo: bar
classes: aaa bbb ccc
---

## AAA{#aaah2}

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam volutpat faucibus vestibulum.
Mauris varius orci quam. Nam dui mauris, dictum at elementum at, mollis pulvinar est.
Nunc lobortis pharetra erat, id rutrum lorem malesuada in.[^ccc]

[^ccc]: foo

## BBB

Phasellus id nisl nec arcu tempor ultricies non id tortor. Mauris ex nibh, viverra vitae nisi eget, placerat pharetra est.
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed id maximus diam. Cras molestie nisl vitae iaculis convallis.
Vivamus molestie vitae nisl sed interdum. Nunc aliquam massa rhoncus finibus convallis.
Vivamus sed vulputate risus. Nunc dignissim magna velit, quis lobortis ex volutpat eget.
Proin dictum mauris condimentum consequat faucibus.[^2]

[^2]: bar

## CCC

* Foo
* Bar
* Baz

<div class="columnbreak"></div>

## DDD

Suspendisse et gravida nunc. Quisque at felis nisl. Nam eget efficitur nunc.
Vivamus fermentum imperdiet massa, porttitor elementum mauris faucibus scelerisque.
Pellentesque ut metus tortor. Fusce vulputate ex at turpis consectetur, in vestibulum odio placerat.
Suspendisse tempor sapien rutrum, cursus sem a, tincidunt odio. Sed in consequat augue.
Proin finibus felis neque, ac hendrerit lorem consequat nec.

## EEE

**Orci varius** _natoque penatibus_ et magnis dis parturient montes, nascetur ridiculus mus. Fusce quam mi, dapibus et augue sit amet, porttitor volutpat orci.
Vestibulum ac ligula at justo placerat pulvinar vel non velit. Duis vel iaculis nibh, non tristique lectus.
Phasellus vel ex bibendum, accumsan tellus a, commodo nisi.
